@@ -17,26 +17,23 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = ( 'parse' );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our $zip;
 
 # Preloaded methods go here.
 
-sub new
-{
+sub new {
   my $package = shift;
   
   $zip = Archive::Zip->new();
   return bless({}, $package);
 }
 
-sub getValues
-{
+sub getValues {
   my(@zStrings) = $zip->membersMatching('^xl/sharedStrings');
   
-  if ($#zStrings > 0)
-  {
+  if ($#zStrings > 0) {
     warn "Error: Multiple shared strings are not [yet] supported\n";
   }
   
@@ -46,21 +43,18 @@ sub getValues
   my($tstrings) = $xml->XMLin($sstrings);
   
   my(@strings);
-  for my $idx (0 .. $#{$tstrings->{'si'}})
-  {
+  for my $idx (0 .. $#{$tstrings->{'si'}}) {
     push @strings, $tstrings->{'si'}->[$idx]->{'t'};
   }
   
   return @strings;
 }
 
-sub getWorksheets
-{
+sub getWorksheets {
   return $zip->membersMatching('^xl/worksheets');
 }
 
-sub getStyles
-{
+sub getStyles {
   my(@zStyles) = $zip->membersMatching('^xl/styles');
   my($data) = $zStyles[0]->contents();
   
@@ -76,45 +70,38 @@ sub getStyles
   my($xborders) = $data->{'borders'}->{'border'};
   
   my($idx) = 0;
-  for my $ind (0 .. $#{$xfonts})
-  {
-    $fonts{$idx} =
-    {
-      'Name'    => $xfonts->[$ind]->{'name'}->{'val'},
-      'Size'    => $xfonts->[$ind]->{'sz'}->{'val'},
-      'Bold'    => defined $xfonts->[$ind]->{'b'} ? '1' : '0'
-    };
+  if (ref($xfonts)) {
+    for my $ind (0 .. $#{$xfonts}) {
+      $fonts{$idx} = {
+        'Name'    => $xfonts->[$ind]->{'name'}->{'val'},
+        'Size'    => $xfonts->[$ind]->{'sz'}->{'val'},
+        'Bold'    => defined $xfonts->[$ind]->{'b'} ? '1' : '0'
+      };
     
-    $idx++;
+      $idx++;
+    }
   }
   
   $idx = 0;
-  for my $ind (0 .. $#{$xborders})
-  {
-    $borders{$idx} =
-    {
-      'Left'      =>
-      {
+  for my $ind (0 .. $#{$xborders}) {
+    $borders{$idx} = {
+      'Left'      => {
         'Color' => defined $xborders->[$ind]->{'left'}->{'color'}->{'indexed'} ? $xborders->[$ind]->{'left'}->{'color'}->{'indexed'} : '',
         'Style' => defined $xborders->[$ind]->{'left'}->{'style'} ? $xborders->[$ind]->{'left'}->{'style'} : ''
       },
-      'Right'     => 
-      {
+      'Right'     => {
         'Color' => defined $xborders->[$ind]->{'right'}->{'color'}->{'indexed'} ? $xborders->[$ind]->{'right'}->{'color'}->{'indexed'} : '',
         'Style' => defined $xborders->[$ind]->{'right'}->{'style'} ? $xborders->[$ind]->{'right'}->{'style'} : ''
       },
-      'Top'       => 
-      {
+      'Top'       => {
         'Color' => defined $xborders->[$ind]->{'top'}->{'color'}->{'indexed'} ? $xborders->[$ind]->{'top'}->{'color'}->{'indexed'} : '',
         'Style' => defined $xborders->[$ind]->{'top'}->{'style'} ? $xborders->[$ind]->{'left'}->{'top'} : ''
       },
-      'Bottom'    => 
-      {
+      'Bottom'    => {
         'Color' => defined $xborders->[$ind]->{'bottom'}->{'color'}->{'indexed'} ? $xborders->[$ind]->{'bottom'}->{'color'}->{'indexed'} : '',
         'Style' => defined $xborders->[$ind]->{'bottom'}->{'style'} ? $xborders->[$ind]->{'bottom'}->{'style'} : ''
       },
-      'Diagonal'  => 
-      {
+      'Diagonal'  => {
         'Color' => defined $xborders->[$ind]->{'diagonal'}->{'color'}->{'indexed'} ? $xborders->[$ind]->{'diagonal'}->{'color'}->{'indexed'} : '',
         'Style' => defined $xborders->[$ind]->{'diagonal'}->{'style'} ? $xborders->[$ind]->{'diagonal'}->{'style'} : ''
       }
@@ -124,11 +111,9 @@ sub getStyles
   }
   
   $idx = 0;
-  for my $ind (0 .. $#{$xcellFormats})
-  {
+  for my $ind (0 .. $#{$xcellFormats}) {
     my($bix) = $xcellFormats->[$ind]->{'borderId'};
-    push @cellFormats,
-    {
+    push @cellFormats, {
       'fillId'    => $xcellFormats->[$ind]->{'fillId'},
       'Font'      => $fonts{$xcellFormats->[$ind]->{'fontId'}},
       'xfId'      => $xcellFormats->[$ind]->{'xfId'},
@@ -142,13 +127,11 @@ sub getStyles
   return \@cellFormats;
 }
 
-sub parse
-{
+sub parse {
   my($self, $file) = @_;
   
   my($ret) = $zip->read($file);
-  unless ($ret == AZ_OK)
-  {
+  unless ($ret == AZ_OK) {
     warn "Unable to read file \"$file\" ($!)\n";
     return undef;
   }
@@ -163,12 +146,9 @@ sub parse
   $worksheets{'Worksheets'} = [];
   
   $worksheets{'Total Worksheets'} = ($#zWorksheets + 1);
-  for my $file (@zWorksheets)
-  {
+  for my $file (@zWorksheets) {
     my(%worksheet);
-    
     my($contents) = $file->contents();
-    
     my($name) = basename($file->fileName());
     $name =~ s/\.xml$//;
     
@@ -179,8 +159,7 @@ sub parse
     my($sMerge) = $data->{'mergeCells'}->{'mergeCell'};
     
     my(%merge);
-    for my $mc (@{$sMerge})
-    {
+    for my $mc (@{$sMerge}) {
       my($from, $to) = split(':', $mc->{'ref'});
       
       $from =~ /([a-zA-Z]+)([0-9]+)/;
@@ -189,47 +168,45 @@ sub parse
       $to =~ /([a-zA-Z]+)([0-9]+)/;
       my($col2, $row2) = ($1, $2);
       
-      $merge{$row1} =
-      {
+      $merge{$row1} = {
         'From' => { 'Row' => $row1, 'Column' => $col1 },
         'To' => { 'Row' => $row2, 'Column' => $col2 }
       };
-      
-      #print "from: $from [$col1, $row1] to: $to [$col2, $row2]\n";
     }
     
     my(@tcol);
-    for my $col (0 .. $#{$sData->[0]->{'c'}})
-    {
+    for my $col (0 .. $#{$sData->[0]->{'c'}}) {
       push @tcol, $sData->[0]->{'c'}->[$col]->{'r'};
     }
     $worksheet{'Columns'} = \@tcol;
     
     my(@trow);
     my(%tdata);
-    for my $row (0 .. $#{$sData})
-    {
+    for my $row (0 .. $#{$sData}) {
       my($cols) = $sData->[$row]->{'c'};
       
       my(@rdata);
       my(@sdata);
-      for my $col (0 .. $#{$cols})
-      {
-        if (!defined $cols->[$col]->{'v'})
-        {
+      for my $col (0 .. $#{$cols}) {
+        if (!defined $cols->[$col]->{'v'}) {
           push @rdata, '';
         }
-        else
-        {
-          push @rdata, ($cols->[$col]->{'t'} eq 's' ?  $strings[$cols->[$col]->{'v'}] : $cols->[$col]->{'v'});
+        else {
+          if (defined $cols->[$col]->{'t'}) {
+            push @rdata, ($cols->[$col]->{'t'} eq 's' ?  $strings[$cols->[$col]->{'v'}] : $cols->[$col]->{'v'});
+          }
         }
 
-        push @sdata, $styles->[$cols->[$col]->{'s'}];
+        if (defined $styles->[$cols->[$col]->{'s'}]) {
+          push @sdata, $styles->[$cols->[$col]->{'s'}];
+        }
       }
 
-      push @trow, $sData->[$row]->{'r'};
-      $tdata{$sData->[$row]->{'r'}}{'Data'} = \@rdata;
-      $tdata{$sData->[$row]->{'r'}}{'Style'} = \@sdata;
+      if (defined $sData->[$row]->{'r'}) {
+        push @trow, $sData->[$row]->{'r'};
+        $tdata{$sData->[$row]->{'r'}}{'Data'} = \@rdata;
+        $tdata{$sData->[$row]->{'r'}}{'Style'} = \@sdata;
+      }
     }
     
     $worksheet{'Rows'} = \@trow;
@@ -277,7 +254,7 @@ of the XLSX file and XML::Simple for parsing the contents.
 
 =head1 AUTHOR
 
-Joe Estock, E<lt>jestock@nutextonline.comE<gt>
+Joe Estock, E<lt>jestock@blendernet.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
